/**
 *
 * @author    Jerry Bendy
 * @since     17/1/4
 * @copyright MicroBenefits
 */

import callBridge from './utils/callBridge'

/**
 *
 * @param pageName
 * @param data
 * @returns {{}|void}
 */
function openPage (pageName, data) {
    // 当打开的是网页时，判断 URL 是否是以 '//' 开头，
    // 如果是，就在其前面添加 http 或 https 前缀
    if (pageName === 'WEB_PAGE') {
        var url = data.url || ''
        if (/^\/\//.test(url)) {
            data.url = location.protocol + url
        }
    }

    callBridge('OPEN_PAGE', {
        pageName: pageName,
        data: data || {}
    })
}


/**
 * 打开 web 页面
 *
 * @param url
 * @param title
 * @param otherParams
 */
openPage.webPage = function (url, title, otherParams) {
    openPage('WEB_PAGE', Object.assign({
        url: url,
        title: title
    }, otherParams));
};


/**
 * 打开扫描二维码页面
 */
openPage.scanning = function () {
    openPage('SCANING');
};


/**
 * 打开用户中心
 * @param userId 用户 ID
 * @param avatar 用户头像
 * @param realName 用户真实姓名
 */
openPage.userCenter = function (userId, avatar, realName) {
    openPage('USERCENTER', {
        userId: userId,
        avatar: avatar || '',
        realName: realName || ''
    });
};


/**
 * 打开任务列表
 */
openPage.taskList = function () {
    openPage('TASK');
};


/**
 * 打开指定任务
 *
 * @param params 未封装的任务参数，详见文档
 */
openPage.task = function (params) {
    openPage('TASK_DETAIL', params);
};


/**
 * 打开课程集
 */
openPage.courseLibrary = function () {
    openPage('COURSE');
};


/**
 * 打开指定课程集
 *
 * @param id 课程集 ID
 * @param title 课程集名称
 * @param thumb 课程集缩略图
 * @param categoryName 课程集分类名（可选）
 */
openPage.courseSet = function (id, title, thumb, categoryName) {
    openPage('COURSE_SET_DETAIL', {
        id: id,
        title: title || '',
        thumb: thumb || '',
        categoryName: categoryName || ''
    });
};

/**
 * 打开课程学习页面
 *
 * @param courseSetId
 * @param courseId
 * @param title  可选的课程标题（APP 需要）
 */
openPage.coursePage = function (courseSetId, courseId, title) {
    openPage('COURSE_PAGE', {
        courseSetId: courseSetId,
        courseId: courseId,
        title: title || ''
    });
};

/**
 * 打开课程挑战（仅 Web 端）
 * @param courseId
 * @param title  可选的课程标题（APP 需要）
 */
openPage.quiz = function(courseId, title) {
    openPage('COURSE_QUIZ', {
        courseId: courseId,
        title: title || ''
    })
};

/**
 * 打开指定用户的用户中心
 *
 * @param userId
 * @param avatar
 * @param realName
 */
openPage.userCenter = function (userId, avatar, realName) {
    openPage('USERCENTER', {
        userId: userId,
        avatar: avatar,
        realName: realName
    });
};

/**
 * 打开成就
 *
 * @param params
 */
openPage.achievement = function (params) {
    openPage('ACHIEVEMENT', params);
};


/**
 * 打开评论模块
 *
 * @param topicId 评论 ID
 * @param title 评论标题
 * @param isAudit 是否审核，bool 值
 * @param limitTime 评论时间段，值为以中划线分隔的两个 UNIX 时间
 */
openPage.comment = function (topicId, title, isAudit, limitTime) {
    var param;
    if (typeof topicId === 'object' && !title && !isAudit && !limitTime) {
        param = topicId
    } else {
        param = {
            topicId: topicId,
            title: title,
            isAudit: isAudit,
            limitTime: limitTime || ''
        }
    }
    prompt('JS_BRIDGE_OPEN_COMMENT', JSON.stringify(param));
};


/**
 * 打开与指定联系人的聊天界面
 *
 * @param userId 好友的用户 ID
 * @param userName 好友昵称
 */
openPage.chat = function (userId, userName){
    openPage('PERSON_CHAT', {
        fId: userId,
        fName: userName
    });
};


/**
 * 打开指定群组的群聊界面
 *
 * @param groupId 群组 ID
 * @param groupName 群组名称
 */
openPage.groupChat = function (groupId, groupName) {
    openPage('GROUP_CHAT', {
        tId: groupId,
        tName: groupName
    });
};

export default openPage;
