/**
 *
 * @author    Jerry Bendy
 * @since     10/20/2017
 */
import checkAccess from '../utils/checkAccess'

var p = window.prompt,
    s = JSON.stringify,
    isAccessible = true   // 是否可访问 JS Bridge 资源

/**
 * 定义一些需要特殊处理的方法
 */
var extraBridges = {
    /**
     * 初始化
     */
    INIT: function() {
        if (!checkAccess()) {
            isAccessible = false
        }
    },

    JS_BRIDGE_UPLOAD_PIC: function(data) {
        var callback = data.callback;

        window._$uploadPicHandler = function(ret) {
            try {
                var parsed = JSON.parse(ret);
                callback(parsed.imgUrl);

            } catch (e) {
                callback('');
            }
        };

        var result = p('JS_BRIDGE_UPLOAD_PIC', s({
            callback: '_$uploadPicHandler'
        }));

        if (result) {
            window._$uploadPicHandler(result);
        }
    },

    /**
     * 图片预览
     *
     * @param data
     * @returns {string}
     */
    JS_BRIDGE_SHOW_IMAGE: function(data) {
        var imageUrl = data.imageUrl,
            currentPos = data.currentPos

        if (imageUrl.length === 1) {
            return p('JS_BRIDGE_OPEN_IMAGE', s({
                imgUrl: imageUrl[0]
            }));
        }

        if (currentPos >= imageUrl.length) currentPos = imageUrl.length - 1

        return p('JS_BRIDGE_OPEN_IMAGE_LIST', s({
            data: imageUrl,
            currImgUrl: imageUrl[currentPos]
        }));
    },

    /**
     * 设置右上角操作按钮
     *
     * @param params
     * @constructor
     */
    JS_BRIDGE_SET_RIGHT_BUTTON: function(params) {
        window._$rightButtonHandler = function() {
            params.callback()
        }

        p('JS_BRIDGE_SET_RIGHT_BUTTON', s({
            buttonName: params.buttonName,
            buttonClickHandle: '_$rightButtonHandler'
        }))
    }
}


/**
 * 直接调用 JS Bridge 方法，并对返回值尝试解析，如果传入数据中包含成功或失败的
 * 回调会直接使用该回调，同时返回最终值到调用方
 *
 * @param key
 * @param data
 * @returns {null|object}
 */
export default function(key, data) {
    if (!isAccessible) {
        return null;
    }

    if (typeof extraBridges[key] === 'function') {
        return extraBridges[key](data)
    }

    return p(key, s(data))
}

