/**
 *
 * @author    Jerry Bendy
 * @since     7/23/2018
 */

/**
 * 获取一个相对时间，主要解决 iOS8 不支持 performance 的情况
 * @returns {number}
 */
function performanceNow() {
    return window.performance ? performance.now() : Date.now()
}

export default {
    /**
     * fadeIn 或 fadeOut 效果
     * @param $el  HTML 元素
     * @param method 方法，可选值为 in 或 out
     * @param speedInMs 动画效果执行的时长，以毫秒为单位
     * @param callback  动画执行完成后的回调方法
     */
    fade: function($el, method, speedInMs, callback) {
        var isIn = method === 'in';
        $el.style.opacity = isIn ? '0' : '1';

        var startTime = performanceNow(),
            timer,
            setOpacity = function() {
                var diff = performanceNow() - startTime;
                if (diff > speedInMs) {
                    $el.style.opacity = isIn ? '1' : '0';
                    cancelAnimationFrame(timer)
                    typeof callback === 'function' && callback()
                    return
                }

                var ratio = diff / speedInMs;
                $el.style.opacity = isIn ? ratio : 1 - ratio;
                timer = requestAnimationFrame(setOpacity)
            }

        timer = requestAnimationFrame(setOpacity)
    }
}
